/******************************************************************************
USB-RAD121 Example Code
    Copyright (C) 2013 Magnii Technologies, LLC
    http://www.magnii.com/
    Release Date: May 4, 2013

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
******************************************************************************/

#include "stdafx.h"
#include <stdio.h>
#include <time.h>
#include "CUSB_RAD121.h"

int _tmain(int argc, _TCHAR* argv[])
{
    CUSB_RAD121 counter;
    double cpm, cmp_compensated, mR_hr;
    int i;

    // Open the device connection
    if( counter.Open() )
    {
        printf( "Connected to device...  Please wait while we gather counts...\r\n" );

        // Turn the device beep ON
        counter.SetDeviceBeep( true );

        // Take 10 readings from the device
        for( i = 0; i < 10; i++ )
        {
            // Wait while the unit gather counts
            // The time we wait directly affects the resolution of our reading
            // For low level readings, long (30 seconds to several minutes) is
            // recommended for accurate readings.
            Sleep( 15000 );    // Wait 15 seconds

            // Get the reading from the unit
            if( counter.GetReading( &cpm ) )
            {
                // Calculate the compensated CPM
                // This compensates for the geiger tube dead time
                cmp_compensated = CUSB_RAD121::Calculate_CompensatedCPM( cpm );

                // Calculate the mR/hr for the compensated CPM value
                mR_hr = CUSB_RAD121::Calculate_mRhr( cmp_compensated );

                // Print the readings to the console
                printf( "cpm=%0.3f, compensated cpm=%0.3f, mR/hr=%0.3f\r\n", cpm, cmp_compensated, mR_hr );
            }
            else
            {
                printf( "Error getting reading!\r\n" );
            }
        }

        // Close the device
        counter.Close();
    }
    else
    {
        printf( "Error opening device!\r\n" );
    }

    // Pause so we can see the console
    system("PAUSE");

    return 0;
}
//---------------------------------------------------------------------------
